import java.util.Iterator;
/**
 * Functions implement the functions that the user can use in the Showboat aplication
 * 
 * @author Jens Bennedsen 
 * @version 20 April 2001
 * modified 20 April 2008 by mec
 * modified 26 April 2009 by Gries
 */
public class Functions {
    // n = # of finished sessions.
    private int n= 0;
    
    // Sum of durations of all finished sessions.
    private Time totalTime= new Time(0);
    
    // The bag of unfinished sessions.
    private Bag current= new Bag();
    
    /** Begin a new session with number nr and
      put it in the bag of current sessions.*/
    public void beginSession (int nr) {
        Session s= new Session(nr);
        System.out.println("Functions.beginSession: starting session number " + nr);
        s.start();
        current.insert(s);
    }
    
    /** Terminate the session with number nr and remove it
        from the bag of current sessions.
        Return value of "a session was removed from the bag" */  
    public boolean endSession (int nr) {
        Session s= current.lookup(nr);
        if (s == null)
            return false;
        
        current.remove(nr);
        s.stop();
        n= n+1;
        totalTime= totalTime.add(s.duration());
        return true;
    }
    
    /** = the information nessesary to make the daily report. */ 
    public ReportInfo doDailyReport() {
        ReportInfo res= new ReportInfo();
        
        if (n != 0)
            res.setAvgTime(totalTime.divide(n));
        else
            res.setAvgTime(new Time(0));
        res.setNrOfSessions(n);
        return res;
    }
    
    /** = the numbers of the current ongoing sessions, with " " after each. */
    public String getStatus() {
        String res= "";
        Iterator i= current.iterator();
        
        while (i.hasNext()) {
            Session s= (Session)(i.next());
            res= res + s.getNr() + " ";
        }
        return res;
    }
}
